@@ -17,6 +17,10 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "GeoIP.h"
 #include "GeoIP_internal.h"
 
@@ -29,6 +33,7 @@
 #include <windows.h>
 #define snprintf _snprintf
 #endif
+
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
