@@ -17,12 +17,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
+ 
+#include <tqfontmetrics.h>
+#include <tqpainter.h>
+#include <tqapplication.h>
+
 #include "headerlistitem.h"
-
-#include <ntqfontmetrics.h>
-#include <ntqpainter.h>
-#include <ntqapplication.h>
-
 #include "uninstallwizard.h"
 #include "wizard.h"
 
