@@ -147,36 +147,36 @@ TorkConfigDialog::TorkConfigDialog( TQWidget *parent, const char* name, TDEConfi
         static_cast<TQLabel*>(label)->setMaximumWidth( 250 );
     delete list;
 
-    connect( m_usability->LongLivedPorts, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_torservers->ExitNodes, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_torservers->ExcludeNodes, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_torservers->MapAddress, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_torservers->AllowUnverifiedNodes, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_firewallsproxies->ReachableAddresses, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_filtertable->FilterRules, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_running->SOCKSPolicy, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_running->SOCKSBindAddressMany, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_running->PushAdd, SIGNAL( clicked() ), this, SLOT( enableApply() ) );
-    connect( m_running->PushAdd2, SIGNAL( clicked() ), this, SLOT( enableApply() ) );
-    connect( m_myserver->kcfg_ClientOnly, SIGNAL( toggled(bool) ), this, SLOT( showServerOpts(bool) ) );
-    connect( m_usability->TrackHostExits, SIGNAL( selectionChanged() ), this, SLOT( enableApply() ) );
-    connect( m_usability->PushAdd, SIGNAL( clicked() ), this, SLOT( enableApply() ) );
+    connect( m_usability->LongLivedPorts, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_torservers->ExitNodes, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_torservers->ExcludeNodes, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_torservers->MapAddress, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_torservers->AllowUnverifiedNodes, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_firewallsproxies->ReachableAddresses, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_filtertable->FilterRules, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_running->SOCKSPolicy, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_running->SOCKSBindAddressMany, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_running->PushAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_running->PushAdd2, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_myserver->kcfg_ClientOnly, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( showServerOpts(bool) ) );
+    connect( m_usability->TrackHostExits, TQ_SIGNAL( selectionChanged() ), this, TQ_SLOT( enableApply() ) );
+    connect( m_usability->PushAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableApply() ) );
 
-    connect( m_quickconfig, SIGNAL( configChanged(const int &) ), this, SLOT( showHidePages(const int &) ) );
-    //connect( m_usability, SIGNAL(settingsChanged()), SLOT(updateButtons()) ); 
+    connect( m_quickconfig, TQ_SIGNAL( configChanged(const int &) ), this, TQ_SLOT( showHidePages(const int &) ) );
+    //connect( m_usability, TQ_SIGNAL(settingsChanged()), TQ_SLOT(updateButtons()) ); 
 
     // Always apply settings when OK or Apply is pressed.
-    //connect( this, SIGNAL(settingsChanged()), this,
-    //               SLOT(updateCustomSettings()) );
-    connect( this, SIGNAL(okClicked()), this,
-                   SLOT(updateCustomSettings()) );
-    connect( this, SIGNAL(applyClicked()), this,
-                   SLOT(updateCustomSettings()) );
-    connect( this, SIGNAL(updateServerButton( )), parent,
-                    SLOT(updateServerButton( )) );
+    //connect( this, TQ_SIGNAL(settingsChanged()), this,
+    //               TQ_SLOT(updateCustomSettings()) );
+    connect( this, TQ_SIGNAL(okClicked()), this,
+                   TQ_SLOT(updateCustomSettings()) );
+    connect( this, TQ_SIGNAL(applyClicked()), this,
+                   TQ_SLOT(updateCustomSettings()) );
+    connect( this, TQ_SIGNAL(updateServerButton( )), parent,
+                    TQ_SLOT(updateServerButton( )) );
 
-    connect( m_firewallsproxies, SIGNAL(uncensorSelected( bool )), parent,
-                                 SLOT(toggleServerButton( bool )) );
+    connect( m_firewallsproxies, TQ_SIGNAL(uncensorSelected( bool )), parent,
+                                 TQ_SLOT(toggleServerButton( bool )) );
 
     if (TorkConfig::currentTorVersion().left(3) == "0.1"){
         m_filtertable->setEnabled(false);
