@@ -37,10 +37,25 @@
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See Tor LICENSE for licensing information */
 /* $Id: crypto.cpp,v 1.11 2008/07/31 19:56:26 hoganrobert Exp $ */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include <kdebug.h>
+
 #include <string.h>
-#include <kdebug.h>  
-#include "crypto.h"
-#include "../config.h"
+#include <stdlib.h>
+#include <assert.h>
+#include <stdio.h>
+#include <limits.h>
+#include <ctype.h>
+#include <unistd.h>
+#include <fcntl.h>
+#include <sys/fcntl.h>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <stdint.h>
 
 #ifndef USE_OPENSSL
 #include <gnutls/gnutls.h>
@@ -59,18 +74,8 @@
 #include <openssl/conf.h>
 #endif
 
-#include <stdlib.h>
-#include <assert.h>
-#include <stdio.h>
-#include <limits.h>
+#include "crypto.h"
 
-#include <ctype.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <sys/fcntl.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <stdint.h>
 
 /* random numbers */
 
@@ -128,7 +133,7 @@ TQString getFPDigestFromFP(const TQString &fp)
     TQString FP = fp;
     FP.replace("$","");
 
-    base16_decode(digest, DIGEST_LEN, FP, strlen(FP));
+    base16_decode(digest, DIGEST_LEN, FP.latin1(), strlen(FP.latin1()));
     digest_to_base64(identity64, digest);
     return identity64;
 }
@@ -158,7 +163,7 @@ TQString getFPFromNickName(const TQString &nickname)
 
     if (fp.isEmpty())
         return TQString();
-    if (!digest_from_base64(buf, fp))
+    if (!digest_from_base64(buf, fp.latin1()))
         base16_encode(hexdigest, HEX_DIGEST_LEN+1, buf, DIGEST_LEN);
 
     return hexdigest;
@@ -169,7 +174,7 @@ TQString getFPFromFPDigest(const TQString &fp)
     char buf[256];
     char hexdigest[HEX_DIGEST_LEN+1];
 
-    digest_from_base64(buf, fp);
+    digest_from_base64(buf, fp.latin1());
     base16_encode(hexdigest, HEX_DIGEST_LEN+1, buf, DIGEST_LEN);
 
     return hexdigest;
