@@ -107,16 +107,16 @@ PopupMessage::PopupMessage( TQWidget *parent, TQWidget *anchor, int timeout, con
         hbox->add( new TQCheckBox( this, "showWarnings" ) );
         static_cast<TQCheckBox*>(child( "showWarnings" ))->setText(TQString("%1 in Future.").arg(m_name));
         static_cast<TQCheckBox*>(child( "showWarnings" ))->setChecked(TRUE);
-        connect( child( "showWarnings" ), SIGNAL(toggled( bool )), SLOT(toggled( bool )) );
+        connect( child( "showWarnings" ), TQ_SIGNAL(toggled( bool )), TQ_SLOT(toggled( bool )) );
     }
     hbox->addItem( new TQSpacerItem( 4, 4, TQSizePolicy::Expanding, TQSizePolicy::Preferred ) );
     hbox->add( new KPushButton( KStdGuiItem::yes(), this, "yesButton" ) );
     hbox->add( new KPushButton( KStdGuiItem::no(), this, "closeButton" ) );
     hbox->add( new KPushButton( KStdGuiItem::ok(), this, "okButton" ) );
 
-    connect( child( "yesButton" ), SIGNAL(clicked()), SLOT(yes()) );
-    connect( child( "closeButton" ), SIGNAL(clicked()), SLOT(no()) );
-    connect( child( "okButton" ), SIGNAL(clicked()), SLOT(no()) );
+    connect( child( "yesButton" ), TQ_SIGNAL(clicked()), TQ_SLOT(yes()) );
+    connect( child( "closeButton" ), TQ_SIGNAL(clicked()), TQ_SLOT(no()) );
+    connect( child( "okButton" ), TQ_SIGNAL(clicked()), TQ_SLOT(no()) );
  
 }
 
