@@ -32,7 +32,7 @@
 
 #include <tdelocale.h>
 #include <assert.h>
-#include <ntqfile.h>
+#include <tqfile.h>
 #include <sys/socket.h>
 #include <netdb.h>
 #include <sys/types.h>
