@@ -54,8 +54,8 @@ void torkview_base::init()
     serverFilter->setSearchColumns(tmp);
 
     clearButton->setIconSet(SmallIconSet("locationbar_erase"));
-    connect(clearButton, SIGNAL( clicked() ),
-                    serverFilter, SLOT(clear()) );
+    connect(clearButton, TQ_SIGNAL( clicked() ),
+                    serverFilter, TQ_SLOT(clear()) );
 
     serverList->addColumn( kapp->iconLoader()->loadIconSet("tork_torsmall", 
                            TDEIcon::Small),"", 24 );
@@ -145,11 +145,11 @@ void torkview_base::streamList_contextMenuRequested( TQListViewItem *, const TQP
     menu->clear();
 
     if (streamList->childCount() > 0)
-        menu->insertItem( "Close Connection", this,SLOT(slotCloseStream()) );
+        menu->insertItem( "Close Connection", this,TQ_SLOT(slotCloseStream()) );
     if (!m_LeaveStreamsUnattached)
-        menu->insertItem( "Let Me Drag Connections To Circuits Myself", this,SLOT(slotAttachStreams()) );
+        menu->insertItem( "Let Me Drag Connections To Circuits Myself", this,TQ_SLOT(slotAttachStreams()) );
     else
-        menu->insertItem( "Attach Connections To Circuits Automatically", this,SLOT(slotAttachStreams()) );
+        menu->insertItem( "Attach Connections To Circuits Automatically", this,TQ_SLOT(slotAttachStreams()) );
 
     menu->popup( point );
 
@@ -185,7 +185,7 @@ void torkview_base::circuitList_contextMenuRequested( TQListViewItem *, const TQ
     TQPopupMenu *menu = new TQPopupMenu( circuitList );
 
     menu->clear();
-    menu->insertItem( "Close Circuit", this,SLOT(slotCloseCircuit()) );
+    menu->insertItem( "Close Circuit", this,TQ_SLOT(slotCloseCircuit()) );
     menu->popup( point );
 
 }
@@ -218,21 +218,21 @@ void torkview_base::serverList_contextMenuRequested( TQListViewItem *, const TQP
     menu->clear();
     menu->insertItem( i18n("For This Session Only"), m_ThisSession );
     menu->insertItem( i18n("From Now On"), m_ThisPerm );
-    menu->insertItem( "Add to My Family", this, SLOT(slotAddToFamily()) );
+    menu->insertItem( "Add to My Family", this, TQ_SLOT(slotAddToFamily()) );
 
     m_ThisSession->insertItem( i18n("Always Use Server As An Exit"), this,
-         SLOT(slotAddSessionStrictExitNodes()) );
-    m_ThisSession->insertItem( i18n("Try To Use Server As an Exit"), this, SLOT(slotAddSessionExitNodes()) );
-    m_ThisSession->insertItem( i18n("Never Use Server At All"), this, SLOT(slotAddSessionExcludeNodes()) );
-    m_ThisSession->insertItem( i18n("Never Use Country At All"), this, SLOT(slotAddSessionExcludeCountry()) );
+         TQ_SLOT(slotAddSessionStrictExitNodes()) );
+    m_ThisSession->insertItem( i18n("Try To Use Server As an Exit"), this, TQ_SLOT(slotAddSessionExitNodes()) );
+    m_ThisSession->insertItem( i18n("Never Use Server At All"), this, TQ_SLOT(slotAddSessionExcludeNodes()) );
+    m_ThisSession->insertItem( i18n("Never Use Country At All"), this, TQ_SLOT(slotAddSessionExcludeCountry()) );
 
-    m_ThisPerm->insertItem( i18n("Always Use Server As An Exit"), this, SLOT(slotAddPermStrictExitNodes()) );
-    m_ThisPerm->insertItem( i18n("Try To Use Server As an Exit"), this, SLOT(slotAddPermExitNodes()) );
-    m_ThisPerm->insertItem( i18n("Never Use Server At All"), this,  SLOT(slotAddPermExcludeNodes()) );
-    m_ThisPerm->insertItem( i18n("Never Use Country At All"), this,  SLOT(slotAddPermExcludeCountry()) );
+    m_ThisPerm->insertItem( i18n("Always Use Server As An Exit"), this, TQ_SLOT(slotAddPermStrictExitNodes()) );
+    m_ThisPerm->insertItem( i18n("Try To Use Server As an Exit"), this, TQ_SLOT(slotAddPermExitNodes()) );
+    m_ThisPerm->insertItem( i18n("Never Use Server At All"), this,  TQ_SLOT(slotAddPermExcludeNodes()) );
+    m_ThisPerm->insertItem( i18n("Never Use Country At All"), this,  TQ_SLOT(slotAddPermExcludeCountry()) );
 
     menu->insertSeparator();
-    menu->insertItem( "Reset Session Settings", this, SLOT(slotClearNodes()) );
+    menu->insertItem( "Reset Session Settings", this, TQ_SLOT(slotClearNodes()) );
     menu->popup( point );
 
 }
@@ -566,9 +566,9 @@ void torkview_base::infoList_contextMenuRequested( TQListViewItem *, const TQPoi
     TQPopupMenu *menu = new TQPopupMenu( infoList );
 
     menu->clear();
-    menu->insertItem( SmallIconSet("copy"), "Copy", this, SLOT(copyLogLines()) );
+    menu->insertItem( SmallIconSet("copy"), "Copy", this, TQ_SLOT(copyLogLines()) );
     menu->insertSeparator();
-    menu->insertItem( "Select All", this, SLOT(selectAllLogLines()) );
+    menu->insertItem( "Select All", this, TQ_SLOT(selectAllLogLines()) );
     menu->popup( point );
 
 }
@@ -580,7 +580,7 @@ void torkview_base::TorTraffic_contextMenuRequested( TQListViewItem *, const TQP
     TQPopupMenu *menu = new TQPopupMenu( TorTraffic );
 
     menu->clear();
-    menu->insertItem( SmallIconSet("help"), "Resolve Hostname/Address", this, SLOT(queryHostName()) );
+    menu->insertItem( SmallIconSet("help"), "Resolve Hostname/Address", this, TQ_SLOT(queryHostName()) );
     menu->popup( point );
 
 }
@@ -638,7 +638,7 @@ void torkview_base::NonTorTraffic_contextMenuRequested( TQListViewItem *, const
     TQPopupMenu *menu = new TQPopupMenu( NonTorTraffic );
 
     menu->clear();
-    menu->insertItem( SmallIconSet("help"), "Resolve Hostname/Address", this, SLOT(queryHostName()) );
+    menu->insertItem( SmallIconSet("help"), "Resolve Hostname/Address", this, TQ_SLOT(queryHostName()) );
     menu->popup( point );
 
 }
