@@ -271,7 +271,7 @@ void TorkUpdate::downloadComponent(TQString component, TQString version, TQStrin
 
                 *arkollonproc << command;
 
-                connect( arkollonproc, SIGNAL(processExited(TDEProcess *)), SLOT(torkInstallationExited(TDEProcess *)) );
+                connect( arkollonproc, TQ_SIGNAL(processExited(TDEProcess *)), TQ_SLOT(torkInstallationExited(TDEProcess *)) );
                 arkollonproc->start();
         }
     }
@@ -409,11 +409,11 @@ void TorkUpdate::startProgressDialog( const TQString & text )
     progressDialog->setMinimumDuration( 500 );
     progressDialog->show();
 
-    connect( progressDialog, SIGNAL( cancelClicked() ), this,
-		SLOT( updateCanceled() ) );
+    connect( progressDialog, TQ_SIGNAL( cancelClicked() ), this,
+		TQ_SLOT( updateCanceled() ) );
 
     timer = new TQTimer( this );
-    connect( timer, SIGNAL( timeout() ), this, SLOT( slotProg() ) );
+    connect( timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( slotProg() ) );
 
     timer->start( 200, FALSE );
 }
@@ -443,7 +443,7 @@ TorkUpdate::checkInternet() //SLOT
     m_url.setHost( "prdownloads.sourceforge.net" ); 
     if ( !m_url.port() ) m_url.setPort( 80 );
 
-    connect( &m_resolver,   SIGNAL( finished( KResolverResults ) ), SLOT( resolved( KResolverResults ) ) );
+    connect( &m_resolver,   TQ_SIGNAL( finished( KResolverResults ) ), TQ_SLOT( resolved( KResolverResults ) ) );
     connectToHost();
 }
 
@@ -457,7 +457,7 @@ TorkUpdate::connectToHost() //SLOT
 
 
 void
-TorkUpdate::resolved( KResolverResults result) // SLOT
+TorkUpdate::resolved( KResolverResults result) //SLOT
 {
     if ((!( result.error() != KResolver::NoError || result.isEmpty() )) 
        /*&& tork_box->isChecked()*/)
@@ -471,8 +471,8 @@ TorkUpdate::resolved( KResolverResults result) // SLOT
 void TorkUpdate::getLatestVersionFromSF(KURL url)
 {
 
-    connect( filelist, SIGNAL( completed() ), this,
-		SLOT( parseSFPage() ) );
+    connect( filelist, TQ_SIGNAL( completed() ), this,
+		TQ_SLOT( parseSFPage() ) );
 
     filelist->setStatusMessagesEnabled(false);
     filelist->openURL(url);
@@ -486,8 +486,8 @@ void TorkUpdate::getLatestVersionFromSFHack(KURL url)
     if (!filelist)
         filelist = new TDEHTMLPart();
 
-    connect( filelist, SIGNAL( completed() ), this,
-		SLOT( parseSFPageHack() ) );
+    connect( filelist, TQ_SIGNAL( completed() ), this,
+		TQ_SLOT( parseSFPageHack() ) );
 
     filelist->setStatusMessagesEnabled(false);
     filelist->openURL(url);
@@ -518,8 +518,8 @@ void TorkUpdate::parseSFPage()
             return;
     }
     
-    disconnect( filelist, SIGNAL( completed() ), this,
-	SLOT( parseSFPage() ) );
+    disconnect( filelist, TQ_SIGNAL( completed() ), this,
+	TQ_SLOT( parseSFPage() ) );
 
     for (unsigned int j=0; j != links.length(); j++ ){
         const DOM::Node linkNode = links.item( j );
@@ -550,8 +550,8 @@ void TorkUpdate::parseSFPageHack()
             return;
     }
     
-    disconnect( filelist, SIGNAL( completed() ), this,
-	SLOT( parseSFPageHack() ) );
+    disconnect( filelist, TQ_SIGNAL( completed() ), this,
+	TQ_SLOT( parseSFPageHack() ) );
 
     for (unsigned int j=0; j != links.length(); j++ ){
         const DOM::Node linkNode = links.item( j );
