@@ -58,7 +58,7 @@ class TDEHTMLPart;
  */
 class TorkUpdate : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
 
