@@ -45,7 +45,7 @@ namespace bt
 	*/
 	class WaitJob : public TDEIO::Job
 	{
-		Q_OBJECT
+		TQ_OBJECT
 	public:
 		WaitJob(Uint32 millis);
 		virtual ~WaitJob();
@@ -164,7 +164,7 @@ namespace kt
 	*/
 	class UPnPRouter : public TQObject
 	{
-		Q_OBJECT
+		TQ_OBJECT
 				
 	public:
 		struct Forwarding 
